@@ -16,7 +16,7 @@ Usage::
     session_client: OutpostsClient = session.client("outposts")
     ```
 """
-from mypy_boto3_outposts.client import OutpostsClient
+from .client import OutpostsClient
 
 Client = OutpostsClient
 
